Effect

Enum Effect 

#[non_exhaustive]
pub enum Effect { Bold, Faint, Italic, Underline, Blink, Reverse, Hidden, Strike, }
Represents the control sequences, named Select Graphic Rendition (SGR), that are used to enable various effects (e.g. italic) on ANSI terminals.

Effects can be combined arbitrarily.

Note: this enum is designed to be immutable and const

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Bold

Effect with SGR parameter 1



Faint

Effect with SGR parameter 2



Italic

Effect with SGR parameter 3



Underline

Effect with SGR parameter 4

Effect with SGR parameter 5



Reverse

Effect with SGR parameter 7



Hidden

Effect with SGR parameter 8



Strike

Effect with SGR parameter 9

Implementations

Source

impl Effect

pub const fn all() -> &'static [Effect]

Get all Effects, which facilitates iterating.

pub const fn attr(&self) -> Attr<Effect>

Creates an Attr with this Effect

pub const fn not(&self) -> Ansi

Creates an Ansi style with the corresponding reset code for this Effect, as follows:

ANSI effectSGR parameter
Bold22
Faint22
Italic23
Underline24
Blink25
Reverse27
Hidden28
Strike29

Note: Bold.not() and Faint.not() have the same parameter

pub const fn only(&self) -> Ansi

Creates an Ansi style with this Effect set to only.

pub const fn important(&self) -> Ansi

Creates an Ansi style with this Effect set to important.

pub const fn ansi(&self) -> Ansi

Used by the styled_*! macros to coerce a style argument to an Ansi instance.