#[non_exhaustive]pub enum Effect {
Bold,
Faint,
Italic,
Underline,
Blink,
Reverse,
Hidden,
Strike,
}Expand description
Represents the control sequences, named Select Graphic Rendition (SGR), that are used to enable various effects (e.g. italic) on ANSI terminals.
Effects can be combined arbitrarily.
Note: this enum is designed to be immutable and const
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Bold
Effect with SGR parameter 1
Faint
Effect with SGR parameter 2
Italic
Effect with SGR parameter 3
Underline
Effect with SGR parameter 4
Blink
Effect with SGR parameter 5
Reverse
Effect with SGR parameter 7
Hidden
Effect with SGR parameter 8
Strike
Effect with SGR parameter 9
Implementations